@@ -5,10 +5,10 @@ import rollbar
 from testcase.app.drilling_efficiency_app import DrillingEfficiency
 
 rollbar_token = os.getenv("ROLLBAR_TOKEN")
-env = os.getenv("APP_ENV")
+env = os.getenv("ENVIRONMENT", os.getenv("APP_ENV"))
+enabled = bool(rollbar_token)
 
-if rollbar_token:
-    rollbar.init(rollbar_token, env, handler='blocking')
+rollbar.init(rollbar_token, env, handler='blocking', enabled=enabled)
 
 
 @rollbar.lambda_function
