@@ -3,7 +3,7 @@ import time
 
 from worker.app.modules.time_activity_module import TimeActivityModule
 from worker.framework import constants
-from worker.data.operations import gather_wits_for_period
+from worker.data.operations import gather_data_for_period
 from worker.framework.mixins import RedisMixin, LoggingMixin, RollbarMixin
 from worker.framework.state import State
 from worker import exceptions
@@ -120,7 +120,7 @@ class App(RedisMixin, LoggingMixin, RollbarMixin):
         end_timestamp = event[-1].get('timestamp')
 
         # the event is converted from scheduler to wits stream
-        scheduler_event = gather_wits_for_period(
+        scheduler_event = gather_data_for_period(
             asset_id=asset_id,
             start=start_timestamp - max_lookback_seconds,
             end=end_timestamp,
@@ -147,7 +147,7 @@ class App(RedisMixin, LoggingMixin, RollbarMixin):
             # Subtract one from the timestamp so that we don't reselect the final data item that was sent in the event
             end_timestamp = first_timestamp - 1
 
-            previous_events = gather_wits_for_period(
+            previous_events = gather_data_for_period(
                 asset_id=asset_id,
                 start=first_timestamp - max_lookback_seconds,
                 end=end_timestamp,
@@ -201,7 +201,7 @@ class App(RedisMixin, LoggingMixin, RollbarMixin):
             return records
 
         else:
-            raise TypeError(f"Event is neither a scheduler, old nor new kafka consumer")
+            raise TypeError("Event is neither a scheduler, old nor new kafka consumer")
 
     @staticmethod
     def determine_asset_id(event: list) -> int:
