@@ -3,6 +3,7 @@ from itertools import groupby
 from worker.app.modules.__init__ import Module
 from worker.data.api import API
 from worker.data import operations
+from worker.exceptions import NotFound
 from worker.framework import constants
 
 
@@ -113,11 +114,7 @@ class ActivityModule(Module):
                     path="/v1/data/corva", collection=self.collection, asset_id=asset_id,
                     sort="{timestamp: -1}", limit=1,
                 ).data
-                if last_document:
-                    last_document = last_document[0]
-                else:
-                    last_document = None
-
+                last_document = last_document[0] if last_document else None
         res = self.configure_output_at_config_change(
             main_structure, active_string_type, active_string_id, warning, last_document
         )
@@ -142,13 +139,18 @@ class ActivityModule(Module):
         self.set_state('active_string_type', active_string_type)
         self.set_state('active_string_id', active_string_id)
 
+        drillstring_number = None
         if active_string_type == 'drillstring':
-            drillstring = API().get_by_id(path="/v1/data/corva/", collection='data.drillstring', id=active_string_id).data
+            drillstring = None
+            try:
+                drillstring = API().get_by_id(path="/v1/data/corva/", collection='data.drillstring', id=active_string_id).data
+            except NotFound:
+                pass
+
             if drillstring:
                 drillstring_number = drillstring.get('data', {}).get('id', None)
-                self.set_state('drillstring_number', drillstring_number)
-        else:
-            self.set_state('drillstring_number', None)
+
+        self.set_state('drillstring_number', drillstring_number)
 
         return self.get_config_properties()
 
