@@ -26,7 +26,7 @@ from distutils.util import strtobool
 from tqdm import tqdm
 
 from worker import constants
-from worker.data.operations import delete_collection_data_of_asset_id, get_one_wits_record, gather_wits_for_period
+from worker.data.operations import delete_collection_data_of_asset_id, get_one_data_record, gather_data_for_period
 from worker.framework.mixins import RedisMixin
 from worker.test.utils import get_last_processed_timestamp, create_scheduler_events
 
@@ -71,9 +71,9 @@ class AppTestRun:
         app_redis = "corva/{0}.{1}".format(asset_id, constants.get("global.app-key"))
 
         if not start_timestamp:
-            start_timestamp = get_one_wits_record(asset_id, timestamp_sort=+1).get('timestamp')
+            start_timestamp = get_one_data_record(asset_id, timestamp_sort=+1).get('timestamp')
         if not end_timestamp:
-            end_timestamp = get_one_wits_record(asset_id, timestamp_sort=-1).get('timestamp')
+            end_timestamp = get_one_data_record(asset_id, timestamp_sort=-1).get('timestamp')
         if to_delete:
             RedisMixin.delete_states(pattern=f"{app_redis}*")
             delete_collection_data_of_asset_id(asset_id, self.collections)
@@ -90,7 +90,7 @@ class AppTestRun:
         for e in self.progress:
             schedule_time = str(int(e[0][0]['schedule_start'] / 1000))
             if self.event_type == "wits_stream":
-                wits = gather_wits_for_period(
+                wits = gather_data_for_period(
                     int(e[0][0]['asset_id']),
                     int(e[0][0]['schedule_start'] / 1000),
                     int(e[0][0]['schedule_end'] / 1000)
